@@ -20,10 +20,22 @@ from .options.InboxOptions import InboxOptions
 from .Guild import Guild
 from .options.GuildOptions import GuildOptions
 from .enum.GuildJoinPolicy import GuildJoinPolicy
+from .LastGuildMasterActivity import LastGuildMasterActivity
+from .options.LastGuildMasterActivityOptions import LastGuildMasterActivityOptions
 from .RoleModel import RoleModel
 from .options.RoleModelOptions import RoleModelOptions
 from .Member import Member
 from .options.MemberOptions import MemberOptions
 from .ReceiveMemberRequest import ReceiveMemberRequest
 from .options.ReceiveMemberRequestOptions import ReceiveMemberRequestOptions
+from .IgnoreUser import IgnoreUser
+from .options.IgnoreUserOptions import IgnoreUserOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
