@@ -17,4 +17,12 @@ from .GlobalMessage import GlobalMessage
 from .options.GlobalMessageOptions import GlobalMessageOptions
 from .TimeSpan import TimeSpan
 from .options.TimeSpanOptions import TimeSpanOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
