@@ -14,7 +14,7 @@
 from __future__ import annotations
 from typing import *
 from .TargetCounterModel import TargetCounterModel
-from ...core.model import ConsumeAction
+from ...core.model import VerifyAction
 from ...core.model import AcquireAction
 from .MissionTaskModel import MissionTaskModel
 from .options.MissionGroupModelOptions import MissionGroupModelOptions
